Processor.processor.Listener — CommonCrawl Extractor 1.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# Processor.processor.Listener

class Processor.processor.Listener(messages: Queue[Message], listener_stats: ListnerStats)
  __init__(messages: Queue[Message], listener_stats: ListnerStats)

  Methods

  `__init__`(messages, listener_stats) |
  `on_before_message`(frame) | Called by the STOMP connection before a message is returned to the client app.
  `on_connected`(frame) | Called by the STOMP connection when a CONNECTED frame is received (after a connection has been established or re-established).
  `on_connecting`(host_and_port) | Called by the STOMP connection once a TCP/IP connection to the STOMP server has been established or re-established.
  `on_disconnected`() | Called by the STOMP connection when a TCP/IP connection to the STOMP server has been lost.
  `on_disconnecting`() | Called before a DISCONNECT frame is sent.
  `on_error`(frame) | Called by the STOMP connection when an ERROR frame is received.
  `on_heartbeat`() | Called on receipt of a heartbeat.
  `on_heartbeat_timeout`() | Called by the STOMP connection when a heartbeat message has not been received beyond the specified period.
  `on_message`(frame) | Called by the STOMP connection when a MESSAGE frame is received.
  `on_receipt`(frame) | Called by the STOMP connection when a RECEIPT frame is received, sent by the server if requested by the client using the 'receipt' header.
  `on_receiver_loop_completed`(frame) | Called when the connection receiver_loop has finished.
  `on_send`(frame) | Called by the STOMP connection when it is in the process of sending a message